@@ -6,7 +6,7 @@ NULL
 #' This class is used to store planning unit points and demand points for a
 #' single species in an attribute space.
 #'
-#' @slot planning.unit.points [PlanningUnitPoints()] for planning
+#' @slot planning.unit.points [PlanningUnitPoints()] object for planning
 #'   unit in the space.
 #'
 #' @slot demand.points [DemandPoints()] object for the space.
@@ -23,21 +23,30 @@ NULL
 #'
 #' @exportClass AttributeSpace
 methods::setClass("AttributeSpace",
-  methods::representation(planning.unit.points = "PlanningUnitPoints",
-                 demand.points = "DemandPoints",
-                 species = "integer"),
+  methods::representation(
+    planning.unit.points = "PlanningUnitPoints",
+    demand.points = "DemandPoints",
+    species = "integer"
+  ),
   validity = function(object) {
-    assertthat::assert_that(isTRUE(ncol(object@demand.points@coords) ==
-                                   ncol(object@planning.unit.points@coords)),
-                                   msg = paste0("argument to pu must have ",
-                                                "same dimensionality as ",
-                                                "argument to demand.points"))
-    assertthat::assert_that(all(is.finite(object@species)),
-                            msg = paste0("argument to species contains NA ",
-                                         "or non-finite value"))
-    assertthat::assert_that(assertthat::is.scalar(object@species),
-                            msg = paste0("argument to species must contain a ",
-                                         "single integer"))
+    assertthat::assert_that(
+      identical(
+        ncol(object@demand.points@coords),
+        ncol(object@planning.unit.points@coords)
+      ),
+      msg = paste0(
+        "argument to pu must have same dimensionality as ",
+        "argument to demand.points"
+      )
+    )
+    assertthat::assert_that(
+      all(is.finite(object@species)),
+      msg = "argument to species contains NA or non-finite value"
+    )
+    assertthat::assert_that(
+      assertthat::is.scalar(object@species),
+      msg = "argument to species must contain a single integer"
+    )
     return(TRUE)
   }
 )
@@ -51,27 +60,35 @@ methods::setClass("AttributeSpace",
 #'
 #' @param demand.points [DemandPoints()] object for the space.
 #'
-#' @param species `integer` species id to indicate which species the space
-#'   is associated with.
+#' @param species `integer` species identifier to indicate which species the
+#'   space is associated with.
 #'
-#' @seealso [DemandPoints-class],
-#'   [PlanningUnitPoints-class].
+#' @return A new `AttributeSpace` object.
+#'
+#' @seealso [DemandPoints-class], [PlanningUnitPoints-class].
 #'
 #' @examples
+#' \dontrun{
 #' space <- AttributeSpace(
 #'  PlanningUnitPoints(
 #'    matrix(rnorm(100), ncol = 2),
-#'    seq_len(50)),
+#'    seq_len(50)
+#'  ),
 #'  DemandPoints(
 #'    matrix(rnorm(100), ncol = 2),
-#'    runif(50)),
-#'  species = 1L)
-#'
+#'    runif(50)
+#'   ),
+#'  species = 1L
+#' )
+#' }
 #' @export
 AttributeSpace <- function(planning.unit.points, demand.points, species) {
-  asp <- methods::new("AttributeSpace",
-                      planning.unit.points = planning.unit.points,
-                      demand.points = demand.points, species = species)
+  asp <- methods::new(
+    "AttributeSpace",
+    planning.unit.points = planning.unit.points,
+    demand.points = demand.points,
+    species = species
+  )
   methods::validObject(asp, test = FALSE)
   return(asp)
 }
